## 作用

把日志文件拖动到窗口即可解析日志

## 使用

项目根目录 创建 config.py
里面定义字段 translator数组

```commandline
translators = [SysLogTranslator(tag_translators=[BluetoothTranslator(), CrashPatternTranslator()])]
```

SysLogTranslator是将文件中每行字符串解析出 tag,time,pid,msg
SysLogTranslator的参数 tag_translators 是数组 用来解析 各种tag对应的内容
解析tag的基类有

- TagPatternTranslator 通过正则匹配tag然后解析
  ```python
  class CrashPatternTranslator(TagPatternTranslator):
       def __init__(self):
           super().__init__({
               r"AndroidRuntime|FATAL.*|System.err.*": activity_task_translator
           })
      
       def activity_task_translator(tag, msg): # 这里两个参数
           # todo 这里需要过滤包名
           return Log(translated=" ------ %s > %s----- " % (tag, msg), level=Level.e)

  ```

- TagStrTranslator 通过字符串匹配tag然后解析
   ```python
  class BluetoothTranslator(TagStrTranslator):
       def __init__(self):
           super().__init__({
               "BluetoothAdapter": bluetooth_adapter,
           })
          
       def bluetooth_adapter(msg):# 这里一个参数
           # todo 这里需要过滤包名
           return Log(translated=" ------ %s > %s----- " % (tag, msg), level=Level.e)

  ```
- SecStrTagTranslator 解析二级tag
   ```python
   class SecTagDemoTranslator(SecStrTagTranslator):
       def __init__(self):
           super().__init__("DFJ",
                            lambda string: re.search(r"(?P<tag>.*?) *:(?P<msg>.*)", string),
                            [
                                SysLogTranslator({
                                    "sec_tag": self.new_tag
                                })
                            ])

       def new_tag(self, tag, msg):# 这里两个参数
           return Log(translated=msg)
  ```

## 打包成 exe

```commandline

pyinstaller -n log_translator --hidden-import config -F -w -i tools.ico ui_pyqt6.py

pyinstaller --hidden-import -n log_translator -F -w -i tools.ico ui_pyside2.py

```

### 库地址

https://pypi.org/project/LogTranslate/0.1/

```commandline
pip install LogTranslate==0.1
```